from helpers.run_process import run_process
from vt100logging import I


def check_for(cmd: str):
    try:
        run_process(f'{cmd} --version')
    except Exception as e:
        raise Exception(f"{cmd} is not installed: {e}")


def check_environment():
    I("Checking environment")
    check_for('git')
    check_for('cmake')
    check_for('ninja')



from vt100logging import vt100logging_init, I, E
from helpers.check_environment import check_environment


def main():
    vt100logging_init('embuild')
    try:
        I("START")
        check_environment()
        I("DONE")
    except Exception as e:
        E(e)
        exit(1)


if __name__ == '__main__':
    main()



from vt100logging import D
from subprocess import Popen, PIPE, DEVNULL, STDOUT
from os import getcwd
from helpers.verbosity import is_verbose


def run_process(cmd: str, cwd: str = getcwd()) -> str:
    """Run a process and return its output."""
    if is_verbose:
        D(f"Running: '{cmd}'")
    process = Popen(cmd, cwd=cwd, stdout=PIPE if is_verbose else DEVNULL,
                    stderr=STDOUT if is_verbose else DEVNULL, shell=True)
    output = process.communicate()[0]
    if process.returncode != 0:
        raise Exception(f"Failed to run: '{cmd}'")
    return output.decode('utf-8')
